@@ -74,9 +74,16 @@ bonobo_activation_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_i
 {
 	int dumb_argc = 1;
 	char *dumb_argv[] = {NULL};
+        BonoboActivationBaseService base_service = {};
 
 	bonobo_activation_postinit (program, mod_info);
 
+        base_service.name = "IDL:Bonobo/ActivationContext:1.0";
+        base_service.session_name = bonobo_activation_session_name_get ();
+        base_service.domain = "session";
+
+        bonobo_activation_service_get (&base_service);
+
 	dumb_argv[0] = program_invocation_name;
 	(void) bonobo_activation_orb_init (&dumb_argc, dumb_argv);
 }
@@ -510,7 +517,6 @@ GnomeModuleInfo gnome_vfs_module_info = {
 };
 
 static GnomeModuleRequirement libgnome_requirements [] = {
-	{ VERSION, &libbonobo_module_info },
 	{ VERSION, &libbonobo_module_info },
 	{ "0.3.0", &gnome_vfs_module_info },
 	{ NULL }
