@@ -15,16 +15,6 @@ G_BEGIN_DECLS
 GType gnome_file_domain_get_type (void);
 
 
-/* --- gnome-sound.h --- */
-#define GNOME_TYPE_SOUND_ERROR gnome_sound_error_get_type()
-GType gnome_sound_error_get_type (void);
-
-
-/* --- gnome-triggers.h --- */
-#define GNOME_TYPE_TRIGGER_TYPE gnome_trigger_type_get_type()
-GType gnome_trigger_type_get_type (void);
-
-
 /* --- gnome-url.h --- */
 #define GNOME_TYPE_URL_DISPLAY_FLAGS gnome_url_display_flags_get_type()
 GType gnome_url_display_flags_get_type (void);
